@@ -43,6 +43,7 @@ def main():
     parser.add_argument('-n', '--sentences', help="the number of 'sentences' to output. defaults to 5.", type=int, default=5)
     parser.add_argument('-l', '--length', help="set maximum number of characters per sentence.", type=int)
     parser.add_argument('-o', '--overlap', help="the amount of overlap allowed between original text and the output, expressed as a radio between 0 and 1. lower values make it more random. defaults to 0.5", type=float, default=0.5)
+    parser.add_argument('--newline', help="sentences in input file end with newlines rather than with full stops.", action='store_true')
     parser.add_argument('-c', '--combine', help="provide an another input text file with path to be combined with the first.")
     parser.add_argument('-w', '--weight', help="specify the weight to be given to the second text provided with --combine. defaults to 1, and the weight of the initial text is also 1. setting this to 1.5 will place 50 percent more weight on the second text. setting it to 0.5 will place less.", type=float, default=1)
 
@@ -60,17 +61,21 @@ def main():
 
     # concatenate the files into batchfile.txt:
     ###NB: trying to avoid encoding error here:
-    with open(batchfile, 'w', encoding="utf-8") as outfile:    
+    with open(batchfile, 'w') as outfile:    
         for fname in matches:
             with open(fname, encoding="latin-1") as infile:
                 outfile.write(infile.read())
+        outfile.close()
 
     # Get raw text from batchfile as string.
     with open(batchfile, 'r') as f:
         text = f.read()
     
     # Build the model:
-    text_model = markovify.Text(text, state_size=args.statesize)
+    if args.newline :
+        text_model = markovify.NewlineText(text, state_size=args.statesize)
+    else:
+        text_model = markovify.Text(text, state_size=args.statesize)
 
     # Print -n number of randomly-generated sentences
     for i in range(args.sentences):
@@ -88,5 +93,5 @@ def main():
 
     os.unlink(batchfile)
 
-    print('\n:  literary genius has been written to the file ' + args.outfile + '. thanks for playing!')
+    print("\n:  literary genius has been written to the file '" + args.outfile + "'. thanks for playing!")
     sys.exit()
